// Set your directory location to QJPS_GGW. 

clear all

// e.g., cd "~/Dropbox/Separation barrier/ANALYSIS/REPLICATION/CODE/QJPS_GGW"

use "DATA/main_panel.dta", clear

// Load this global

gl controls popN regional_council urban distance2greenline distance2greenline2 

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE 3
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 

gen MonthOfSample=MonthTrend-21

matrix storeTS = J(41, 4, .) 
matrix list storeTS  

forval i=1/41{

gen dateMT=.
replace dateMT=0 if MonthOfSample==`i'
replace dateMT=1 if MonthOfSample==`i'+1

	matrix storeTS[`i', 1] = `i'
	matrix storeTS[`i', 2] = .
	
	quietly ttest carthefts_pc if MonthOfSample==`i'&sample1==1&TS!=., by(TS)
	
	matrix storeTS[`i', 3] = `r(mu_1)'
	matrix storeTS[`i', 4] = `r(mu_2)'

drop dateMT
}

matrix list storeTS  
svmat storeTS, names(ts)

matrix storeTNTS = J(41, 4, .) 
matrix list storeTNTS  

forval i=1/41{

gen dateMT=.
replace dateMT=0 if MonthOfSample==`i'
replace dateMT=1 if MonthOfSample==`i'+1

	matrix storeTNTS[`i', 1] = `i'
	matrix storeTNTS[`i', 2] = .
	
	quietly ttest carthefts_pc if MonthOfSample==`i'&sample1==1&Treatment!=., by(Treatment)
	
	matrix storeTNTS[`i', 3] = `r(mu_1)'
	matrix storeTNTS[`i', 4] = `r(mu_2)'

drop dateMT
}
matrix list storeTNTS  
svmat storeTNTS, names(tnts)

gen perc_tn=tnts4/1.009776
gen perc_ts=tnts3/.8435
gen perc_out=ts3/.3341354 

gen grand_mean=(perc_tn+perc_ts+perc_out)/3

tw (lowess perc_tn tnts1, bw(.25) lcolor(black)) || (lowess perc_ts tnts1, bw(.25) lcolor(black) lpattern(dash)) || (lowess perc_out ts1, bw(.25) lcolor(black) lpattern(shortdash)), xline(21, lc(red)) xscale(range(1 41)) xla(1(5)41) legend(label(1 "Northern") label(2 "Southern") label(3 "Outer")) legend(size(tiny) pos(7) ring(0) col(1) symxsize(5)) graphregion(color(white)) xtitle("Month of Sample") ytitle("Monthly mean of car theft, % of pretreat mean")


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE 4
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*Summarize key stats
summarize  pre_route_kmUP if TN==1, detail
	*90% for TN is 63.7 KM
	
tw (lowess carthefts_pc_prepost pre_route_kmUP if TN==1&date==tm(2002m9)& religion==1 & tamar!=1, bw(0.3) lc(green) yaxis(1) lwidth(vthin)) ///
	|| (lowess leng_diff_perc_minUP pre_route_kmUP if TN==1&date==tm(2002m9)& religion==1 & tamar!=1, bw(0.3) lc(red) lp(dash) yaxis(2) lwidth(vthin)), ///
	legend(size(small) pos(3) ring(0) col(1) order(1 "Pre/Post Diff" 2 "Route Disruption" ))  ///                    
	graphregion( color(white)) ///
	scheme(lean1) ///
	xline(63.7, lcolor(black) lwidth(vthin)) ///
	text(-.21 64 "90th percentile", size(3) place(ne)) ///
	text(-.21 42.5 "Peak cost", size(3) place(ne)) ///
	text(-.73 42.5 "Peak decline", size(3) place(ne)) ///
	ytitle("Mean difference in car theft (per 1000 persons) (post minus pre)", size(3) axis(1)) ytitle("Route disruption (% increase over pretreatment)", size(3) axis(2)) xtitle("Path length to Nablus, KM", size(2.5))


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE SI-6 (A/B/C)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 

gen MT_actual=MonthTo-2

** FIGURE SI-6A

matrix storeTNTS = J(20, 4, .) 
matrix list storeTNTS  

forval i=1/20{

gen dateMT=.
replace dateMT=0 if MT_actual==`i'+1
replace dateMT=1 if MT_actual==`i'

	quietly diff carthefts_pc if sample1==1, t(Treatment) p(dateMT)

	matrix storeTNTS[`i', 1] = `i'
	matrix storeTNTS[`i', 2] = `r(did)'/`r(se_dd)'
	
	quietly ttest carthefts_pc if MT_actual==`i'&sample1==1&Treatment!=., by(Treatment)
	
	matrix storeTNTS[`i', 3] = `r(mu_1)'
	matrix storeTNTS[`i', 4] = `r(mu_2)'

drop dateMT
}
matrix list storeTNTS  

svmat storeTNTS, names(tnts_pre)

gen trend_breakTNTS=2 if (tnts_pre2>1.64|tnts_pre2<-1.64)&tnts_pre2!=.
replace trend_breakTNTS=0 if trend_breakTNTS!=2

gen tnts_pre4_perc=tnts_pre4/1.009776
gen tnts_pre3_perc=tnts_pre3/.8435

tw (bar trend_breakTNTS tnts_pre1, bcolor(gs14) legend(label(1 "Trend break"))) || (lowess tnts_pre4_perc tnts_pre1, bw(.35) lcolor(black) lpattern(dash)  legend(label(2 "Northern")) graphregion(color(white)) xscale(rev) xtitle("Months to treatment") ytitle("Monthly mean of car theft, % of pretreat mean")) || (lowess tnts_pre3_perc tnts_pre1, bw(.35) lcolor(black) lpattern(shortdash) legend(label(3 "Southern")) legend(size(vsmall) pos(1) ring(0) col(1)  symxsize(5)))  


** FIGURE SI-6B

matrix storeTN = J(20, 4, .) 
matrix list storeTN 

forval i=1/20{

gen dateMT=.
replace dateMT=0 if MT_actual==`i'+1
replace dateMT=1 if MT_actual==`i'

	quietly diff carthefts_pc if sample1==1, t(TN) p(dateMT)

	matrix storeTN[`i', 1] = `i'
	matrix storeTN[`i', 2] = `r(did)'/`r(se_dd)'
	
	quietly ttest carthefts_pc if MT_actual==`i'&sample1==1&TN!=., by(TN)
	
	matrix storeTN[`i', 3] = `r(mu_1)'
	matrix storeTN[`i', 4] = `r(mu_2)'

drop dateMT
}

matrix list storeTN

svmat storeTN, names(tn_pre)

gen trend_breakTN=2 if (tn_pre2>1.64|tn_pre2<-1.64)&tn_pre2!=.
replace trend_breakTN=0 if trend_breakTN!=2

gen tn_pre4_perc=tn_pre4/1.009776
gen tn_pre3_perc=tn_pre3/.3341354

tw (bar trend_breakTN tn_pre1, bcolor(gs14) legend(label(1 "Trend break"))) || (lowess tn_pre4_perc tn_pre1, bw(.35) lcolor(black) lpattern(dash) legend(label(2 "Northern")) graphregion(color(white)) xscale(rev) xtitle("Months to treatment") ytitle("Monthly mean of car theft, % of pretreat mean")) || (lowess tn_pre3_perc tn_pre1, bw(.35) lcolor(black)  lpattern(shortdash) legend(label(3 "Outer")) legend(size(vsmall) pos(1) ring(0) col(1)  symxsize(5))) 


** FIGURE SI-6C

matrix storeTS = J(20, 4, .) 
matrix list storeTS  

forval i=1/20{

gen dateMT=.
replace dateMT=0 if MT_actual==`i'+1
replace dateMT=1 if MT_actual==`i'

	quietly diff carthefts_pc if sample1==1, t(TS) p(dateMT)

	matrix storeTS[`i', 1] = `i'
	matrix storeTS[`i', 2] = `r(did)'/`r(se_dd)'
	
	quietly ttest carthefts_pc if MT_actual==`i'&sample1==1&TS!=., by(TS)
	
	matrix storeTS[`i', 3] = `r(mu_1)'
	matrix storeTS[`i', 4] = `r(mu_2)'

drop dateMT
}

matrix list storeTS  
svmat storeTS, names(ts_pre)

gen trend_breakTS=2 if (ts_pre2>1.64|ts_pre2<-1.64)&ts_pre2!=.
replace trend_breakTS=0 if trend_breakTS!=2

gen ts_pre4_perc=ts_pre4/.8435
gen ts_pre3_perc=ts_pre3/.3341354

tw (bar trend_breakTS ts_pre1, bcolor(gs14) legend(label(1 "Trend break"))) || (lowess ts_pre4_perc ts_pre1, bw(.35) lcolor(black)  lpattern(dash)  legend(label(2 "Southern")) graphregion(color(white)) xscale(rev) xtitle("Months to treatment") ytitle("Monthly mean of car theft, % of pretreat mean")) || (lowess ts_pre3_perc ts_pre1, bw(.35) lcolor(black)  lpattern(shortdash) legend(label(3 "Outer")) legend(size(vsmall) pos(1) ring(0) col(1)  symxsize(5))) 


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE SI-7 (A/B/C)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 

gen months_in_sample=MonthRun+23

forval i=1/41{
	gen MonthInSample`i'=0
	replace MonthInSample`i'=1 if months_in_sample==`i'
}

forval i=1/41{
	gen treatXMonthInSample`i'=MonthInSample`i'*Treatment
	gen tnXMonthInSample`i'=MonthInSample`i'*TN
	gen tsXMonthInSample`i'=MonthInSample`i'*TS
}

** SI-7A

quietly reg carthefts_pc  Treatment MonthInSample* treatXMonthInSample* $controls  c.date if sample6==1 , cl(lcode)
	
matrix storeTNTS = J(41, 6, .) 
matrix list storeTNTS  
	
forval i=1/41{
	matrix storeTNTS[`i', 1] = `i'
	matrix storeTNTS[`i', 2] = _b[treatXMonthInSample`i']
	matrix storeTNTS[`i', 3] = _se[treatXMonthInSample`i']
	matrix storeTNTS[`i', 4] = _b[treatXMonthInSample`i']-1.96*_se[treatXMonthInSample`i']
	matrix storeTNTS[`i', 5] = _b[treatXMonthInSample`i']+1.96*_se[treatXMonthInSample`i']
	matrix storeTNTS[`i', 6] = `i'-21

}	
svmat storeTNTS, names(tnts_)

	tw (line tnts_4 tnts_6, lcolor(gs8) lpattern(dash)) || (line tnts_5 tnts_6, lcolor(gs8) lpattern(dash)) || (connected tnts_2 tnts_6, lcolor(black) msymbol(circle hollow) msize(tiny) mcolor(black)), xlabel(-20(2)20) legend(off)  ytitle("Estimated Effects of Lags and Leads") xtitle("Months from Treatment")  graphregion(color(white)) xline(0, lcolor(red)) yline(0, lcolor(gs5) lwidth(vthin))
	
** SI-7B

quietly reg carthefts_pc  TN MonthInSample* tnXMonthInSample* $controls  c.date if sample6==1 , cl(lcode)
	
matrix storeTN = J(41, 6, .) 
matrix list storeTN  
	
forval i=1/41{
	matrix storeTN[`i', 1] = `i'
	matrix storeTN[`i', 2] = _b[tnXMonthInSample`i']
	matrix storeTN[`i', 3] = _se[tnXMonthInSample`i']
	matrix storeTN[`i', 4] = _b[tnXMonthInSample`i']-1.96*_se[tnXMonthInSample`i']
	matrix storeTN[`i', 5] = _b[tnXMonthInSample`i']+1.96*_se[tnXMonthInSample`i']
	matrix storeTN[`i', 6] = `i'-21

}	
svmat storeTN, names(tn_)

	tw (line tn_4 tn_6, lcolor(gs8) lpattern(dash)) || (line tn_5 tn_6, lcolor(gs8) lpattern(dash)) || (connected tn_2 tn_6, lcolor(black) msymbol(circle hollow) msize(tiny) mcolor(black)), xlabel(-20(2)20) legend(off)  ytitle("Estimated Effects of Lags and Leads") xtitle("Months from Treatment")  graphregion(color(white)) xline(0, lcolor(red)) yline(0, lcolor(gs5) lwidth(vthin))

** SI-7C
	
quietly reg carthefts_pc  TS MonthInSample* tsXMonthInSample* $controls  c.date if sample6==1 , cl(lcode)
	
matrix storeTS = J(41, 6, .) 
matrix list storeTS 
	
forval i=1/41{
	matrix storeTS[`i', 1] = `i'
	matrix storeTS[`i', 2] = _b[tsXMonthInSample`i']
	matrix storeTS[`i', 3] = _se[tsXMonthInSample`i']
	matrix storeTS[`i', 4] = _b[tsXMonthInSample`i']-1.96*_se[tsXMonthInSample`i']
	matrix storeTS[`i', 5] = _b[tsXMonthInSample`i']+1.96*_se[tsXMonthInSample`i']
	matrix storeTS[`i', 6] = `i'-21

}	
svmat storeTS, names(ts_)

	tw (line ts_4 ts_6, lcolor(gs8) lpattern(dash)) || (line ts_5 ts_6, lcolor(gs8) lpattern(dash)) || (connected ts_2 ts_6, lcolor(black) msymbol(circle hollow) msize(tiny) mcolor(black)), xlabel(-20(2)20) legend(off)  ytitle("Estimated Effects of Lags and Leads") xtitle("Months from Treatment")  graphregion(color(white)) xline(0, lcolor(red)) yline(0, lcolor(gs5) lwidth(vthin))
	
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE SI-9
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set matsize 800

forval v=25/40{
* Model 1: compare north to south
	replace treat=Treatment_`v'
	quietly reg carthefts_pc treat##PT $controls c.date  if sample1==1 , cl(lcode)
	estimates store ols_TR_m1_PC_`v'

* Model 2: compare north to outside localities
	replace treat=TN_`v'
	quietly reg carthefts_pc treat##PT $controls c.date if sample1==1 , cl(lcode)
	estimates store ols_TN_m1_PC_`v'
	
* Model 3: compare south to outside localities
	replace treat=TS_`v'
	quietly reg carthefts_pc treat##PT $controls  c.date if sample1==1 , cl(lcode)
	estimates store ols_TS_m1_PC_`v'
}

coefplot  (ols_TR_m1_PC_25) (ols_TR_m1_PC_26) (ols_TR_m1_PC_27) (ols_TR_m1_PC_28) (ols_TR_m1_PC_29) (ols_TR_m1_PC_30) (ols_TR_m1_PC_31) (ols_TR_m1_PC_32) (ols_TR_m1_PC_33) (ols_TR_m1_PC_34) (ols_TR_m1_PC_35) (ols_TR_m1_PC_36) (ols_TR_m1_PC_37) (ols_TR_m1_PC_38) (ols_TR_m1_PC_39) (ols_TR_m1_PC_40),  keep(1.treat#1.PT) vertical bgcolor(white) legend(off) xline(0) nolabel graphregion(color(white)) mcolor(black) levels(90) ciopts(lcolor(black)) yline(-0.708) coeflabels(1.treat#1.PT = "Treatment X Post, expanding treatment bandwidth (+1 KM)") 

coefplot  (ols_TN_m1_PC_25) (ols_TN_m1_PC_26) (ols_TN_m1_PC_27) (ols_TN_m1_PC_28) (ols_TN_m1_PC_29) (ols_TN_m1_PC_30) (ols_TN_m1_PC_31) (ols_TN_m1_PC_32) (ols_TN_m1_PC_33) (ols_TN_m1_PC_34) (ols_TN_m1_PC_35) (ols_TN_m1_PC_36) (ols_TN_m1_PC_37) (ols_TN_m1_PC_38) (ols_TN_m1_PC_39) (ols_TN_m1_PC_40),  keep(1.treat#1.PT) vertical bgcolor(white) legend(off) xline(0) nolabel graphregion(color(white)) mcolor(black) levels(90) ciopts(lcolor(black)) yline(-0.415) coeflabels(1.treat#1.PT = "Treatment X Post, expanding treatment bandwidth (+1 KM)") 

coefplot  (ols_TS_m1_PC_25) (ols_TS_m1_PC_26) (ols_TS_m1_PC_27) (ols_TS_m1_PC_28) (ols_TS_m1_PC_29) (ols_TS_m1_PC_30) (ols_TS_m1_PC_31) (ols_TS_m1_PC_32) (ols_TS_m1_PC_33) (ols_TS_m1_PC_34) (ols_TS_m1_PC_35) (ols_TS_m1_PC_36) (ols_TS_m1_PC_37) (ols_TS_m1_PC_38) (ols_TS_m1_PC_39) (ols_TS_m1_PC_40),  keep(1.treat#1.PT) vertical bgcolor(white) legend(off) xline(0) nolabel graphregion(color(white)) mcolor(black) levels(90) ciopts(lcolor(black)) yline(0.292) coeflabels(1.treat#1.PT = "Treatment X Post, expanding treatment bandwidth (+1 KM)") 

eststo clear

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE SI-10
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

forval v=50/65{
* Model 2: compare north to outside localities
	replace treat=TN_`v'
	quietly reg carthefts_pc treat##PT $controls c.date if sample1==1 , cl(lcode)
	estimates store ols_TN_m1_PC_`v'
	
* Model 3: compare south to outside localities
	replace treat=TS_`v'
	quietly reg carthefts_pc treat##PT $controls  c.date if sample1==1 , cl(lcode)
	estimates store ols_TS_m1_PC_`v'
}

coefplot  (ols_TN_m1_PC_50) (ols_TN_m1_PC_51) (ols_TN_m1_PC_52) (ols_TN_m1_PC_53) (ols_TN_m1_PC_54) (ols_TN_m1_PC_55) (ols_TN_m1_PC_56) (ols_TN_m1_PC_57) (ols_TN_m1_PC_58) (ols_TN_m1_PC_59) (ols_TN_m1_PC_60) (ols_TN_m1_PC_61) (ols_TN_m1_PC_62) (ols_TN_m1_PC_63) (ols_TN_m1_PC_64) (ols_TN_m1_PC_65),  keep(1.treat#1.PT) vertical bgcolor(white) legend(off) xline(0) nolabel graphregion(color(white)) mcolor(black) levels(90) ciopts(lcolor(black)) yline(-0.415) coeflabels(1.treat#1.PT = "Treatment X Post, expanding treatment bandwidth (+1 KM)") 

coefplot  (ols_TS_m1_PC_50) (ols_TS_m1_PC_51) (ols_TS_m1_PC_52) (ols_TS_m1_PC_53) (ols_TS_m1_PC_54) (ols_TS_m1_PC_55) (ols_TS_m1_PC_56) (ols_TS_m1_PC_57) (ols_TS_m1_PC_58) (ols_TS_m1_PC_59) (ols_TS_m1_PC_60) (ols_TS_m1_PC_61) (ols_TS_m1_PC_62) (ols_TS_m1_PC_63) (ols_TS_m1_PC_64) (ols_TS_m1_PC_65),  keep(1.treat#1.PT) vertical bgcolor(white) legend(off) xline(0) nolabel graphregion(color(white)) mcolor(black) levels(90) ciopts(lcolor(black)) yline(0.292) coeflabels(1.treat#1.PT = "Treatment X Post, expanding treatment bandwidth (+1 KM)") 

eststo clear
		
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURE SI-13
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*Summarize key stats
summarize  pre_route_kmUP if TS==1, detail
	*90% for TS is 76.7 KM
				
tw (lowess carthefts_pc_prepost pre_route_kmUP if TS==1&date==tm(2002m9)& religion==1 & tamar!=1, bw(0.3) lp(shortdash) lc(red) lwidth(vthin)), ///
	graphregion(color(white)) ///
	scheme(lean1) ///
	xline(76.7, lcolor(black) lwidth(vthin)) ///
	text(.4 77 "90th percentile", size(3) place(ne)) ///
	text(.4 63 "Peak increase", size(3) place(nw)) ///
	ytitle("Mean difference in car theft (per 1000 persons) (post minus pre)", size(3)) xtitle("Path length to Hebron, KM", size(2.5))


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* FIGURES SI-4, SI-5, SI-12. SEE README BELOW. 
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 

* README: Notice, to make this file, you are going to collapse the data. For this reason, these figures are out of sequence with the overall list. 

gen TREATC=TREATB
replace TREATC=3 if TREATC==2&distance2greenline<=5

collapse (sum) car_theft_arrests carthefts WB northern_susp southern_susp outer_susp, by(TREATC date)
gen app_rate=car_theft_arrests/carthefts

gen app_rate_n=northern_susp/carthefts
gen app_rate_s=southern_susp/carthefts
gen app_rate_o=outer_susp/carthefts

gen wall=.051

gen nonWB=car_theft_arrests-WB
gen nonWBapp_rate=nonWB/carthefts

tw (lowess nonWBapp_rate date if TREATC==0&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(shortdash_dot) lc(blue) legend(label(1 "Outer") size(small))) ///
(lowess nonWBapp_rate date if TREATC==1&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(shortdash) lc(gs10) legend(label(2 "South") size(small))) ///
(lowess nonWBapp_rate date if TREATC==2&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(longdash) lc(gs7) legend(label(3 "North (>5 KM from greenline)") size(small))) ///
(lowess nonWBapp_rate date if TREATC==3&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(longdash_dot) lc(gs2) legend(label(4 "North (<5 KM from greenline)") size(small))), ///
scheme(lean1) title("Mean Monthly Apprehension Rates, Israeli suspects", size(4)) ///
tline(2002m6, lc(red)) ///
tlabel( 2001m1 2002m1 2003m1 2004m1) ytitle("Mean app. rate by region", size(3)) xtitle("") ///
legend(ring(1) pos(6) col(2)) 

gen WBapp_rate=WB/carthefts

tw (lowess WBapp_rate date if TREATC==0&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(shortdash_dot) lc(blue) legend(label(1 "Outer") size(small))) ///
(lowess WBapp_rate date if TREATC==1&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(shortdash) lc(gs10) legend(label(2 "South") size(small))) ///
(lowess WBapp_rate date if TREATC==2&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(longdash) lc(gs7) legend(label(3 "North (>5 KM from greenline)") size(small))) ///
(lowess WBapp_rate date if TREATC==3&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lp(longdash_dot) lc(gs2) legend(label(4 "North (<5 KM from greenline)") size(small))), ///
scheme(lean1) title("Mean Monthly Apprehension Rates, West Bank suspects", size(4)) ///
tline(2002m6, lc(red)) ///
tlabel(2001m1 2002m1 2003m1 2004m1) ytitle("Mean app. rate by region", size(3)) xtitle("") ///
legend(ring(1) pos(6) col(2)) 


tw (lowess app_rate_n date if TREATC==1&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lc(black) legend(label(1 "Northern suspects") size(small))) ///
(lowess app_rate_s date if TREATC==1&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lc(blash) lp(longdash) legend(label(2 "Southern suspects") size(small))) ///
(lowess app_rate_o date if TREATC==1&date>tm(2000m10) & date<tm(2004m1), bw(0.25) lc(black) lp(shortdash) legend(label(3 "Outer suspects") size(small))), ///
scheme(lean1) title("Mean Monthly Apprehension Rates in Southern localities", size(4)) ///
tline(2002m6, lc(red)) ///
tlabel(2001m1 2002m1 2003m1 2004m1) ytitle("Mean app. rate, by suspect origin", size(3)) xtitle("") ///
legend(ring(1) pos(6) col(3)) 
