// Set your directory location to QJPS_GGW. 

use "DATA/main_panel.dta", clear

// Load this global

gl controls popN regional_council urban distance2greenline distance2greenline2 

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE 1
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set matsize 800

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.date  if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.date if sample1==1 , cl(lcode)
	
* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls  c.date if sample1==1 , cl(lcode)

	
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE 2
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


* Model 1: compare north to outside localities
	replace treat=TN_RDUP
	reg carthefts_pc c.treat##PT $controls c.date if sample1==1 , cl(lcode)	
	
* Model 2: compare north to outside localities, % disruption
	replace treat=TN_pctUP
	reg carthefts_pc c.treat##PT $controls c.date if sample1==1 , cl(lcode) 
		
* Model 3: compare north to outside localities, KM disruption
	replace treat=TN_rcUP
	reg carthefts_pc c.treat##PT $controls c.date if sample1==1 , cl(lcode)

* Model 4: compare north to outside localities, common vs. common + disruption
	replace treat=TN_base_RDUP
	reg carthefts_pc c.treat##PT c.TN_disr_RDUP##PT $controls c.date if sample1==1 , cl(lcode) 


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-4
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
* Model 1: compare north to south
	replace treat=Treatment
	xtreg carthefts_pc treat##PT $controls i.date if sample1==1 , cl(lcode) fe

* Model 2: compare north to outside localities
	replace treat=TN
	xtreg carthefts_pc treat##PT $controls i.date if sample1==1 , cl(lcode) fe

* Model 3: compare south to outside localities
	replace treat=TS
	xtreg carthefts_pc treat##PT $controls i.date if sample1==1 , cl(lcode) fe

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-5
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gl dv_lags L1.carthefts_pc L2.carthefts_pc L3.carthefts_pc L4.carthefts_pc L5.carthefts_pc

*set panel structure for lags
xtset lcode date

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls $dv_lags c.date if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls $dv_lags c.date if sample1==1 , cl(lcode)
	
* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls $dv_lags c.date if sample1==1 , cl(lcode)


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-6
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set matsize 800

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.date  if sample1==1&MonthTo!=15, cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.date if sample1==1&MonthTo!=5&MonthTo!=20, cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls  c.date if sample1==1&MonthTo!=6&MonthTo!=8, cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-7
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set matsize 800

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.date  if sample5==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.date if sample5==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls  c.date if sample5==1 , cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-8
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set matsize 800

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.date#i.district  if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.date#i.district if sample1==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls  c.date#i.district if sample1==1 , cl(lcode)
 

		
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-9
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.month if sample1==1 , cl(arab_cluster)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.month if sample1==1 , cl(arab_cluster)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls c.month if sample1==1 , cl(arab_cluster)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-10
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.month if sample1==1& lcod!=9000 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.month if sample1==1 & lcod!=9000, cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls c.month if sample1==1 & lcod!=9000, cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-11
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.month if sample2==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.month if sample2==1 , cl(lcode)
	
* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls c.month if sample2==1 , cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-12
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT $controls c.month if sample3==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT $controls c.month if sample3==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT $controls c.month if sample3==1 , cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-13
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT suicide_attacks $controls c.month if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT suicide_attacks $controls c.month if sample1==1 , cl(lcode)
	
* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT suicide_attacks $controls c.month if sample1==1 , cl(lcode)
	
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-14
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT district_suicide_attacks $controls c.month if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT district_suicide_attacks $controls c.month if sample1==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT district_suicide_attacks $controls c.month if sample1==1 , cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-15
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT attacks $controls c.month if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT attacks $controls c.month if sample1==1 , cl(lcode)
	
* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT attacks $controls c.month if sample1==1 , cl(lcode)
	
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-16
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT district_attacks $controls c.month if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT district_attacks $controls c.month if sample1==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT district_attacks $controls c.month if sample1==1 , cl(lcode)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-17
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


* Model 1: compare north to south
	replace treat=Treatment
	reg carthefts_pc treat##PT cluster $controls c.month if sample1==1 , cl(lcode)

* Model 2: compare north to outside localities
	replace treat=TN
	reg carthefts_pc treat##PT cluster $controls c.month if sample1==1 , cl(lcode)

* Model 3: compare south to outside localities
	replace treat=TS
	reg carthefts_pc treat##PT cluster $controls c.month if sample1==1 , cl(lcode)


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* TABLE SI-18
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* PANEL A

*northern localities
reg breakins_pc carthefts_pc $controls c.date if sample1==1&TN==1, cl(lcode)

*southern localities
reg breakins_pc carthefts_pc $controls c.date if sample1==1&TS==1, cl(lcode)

*outer localities
reg breakins_pc carthefts_pc $controls c.date if sample1==1&TS==0, cl(lcode)

* PANEL B

*northern localities		
reg breakins_pc_prepost carthefts_pc_prepost $controls if sample1==1&MonthFrom==12 &TN==1, cl(lcode)

*southern localities
reg breakins_pc_prepost carthefts_pc_prepost $controls if sample1==1&MonthFrom==12 &TS==1, cl(lcode)

*outer localities
reg breakins_pc_prepost carthefts_pc_prepost $controls if sample1==1&MonthFrom==12 &TS==0, cl(lcode)


* PANEL C

*northern localities
reg breakins_pc carthefts_pc_prepost $controls i.date  if sample1==1&PT==1 &TN==1, cl(lcode)

*southern localities
reg breakins_pc carthefts_pc_prepost $controls i.date  if sample1==1&PT==1 &TS==1, cl(lcode)

*outer localities
reg breakins_pc carthefts_pc_prepost $controls i.date  if sample1==1&PT==1 &TS==0, cl(lcode)


